@@ -3,6 +3,7 @@ import json
 import os
 import re
 import sys
+import shlex
 import base64
 import hashlib
 
@@ -11,19 +12,24 @@ import delegator
 import pipfile
 import toml
 
+from .patched.pip.baseparser import ConfigOptionParser
 from .utils import (
     mkdir_p, convert_deps_from_pip, pep423_name, recase_file,
     find_requirements, is_file, is_vcs, python_version, cleanup_toml,
-    is_installable_file, is_valid_url
+    is_installable_file, is_valid_url, normalize_drive
+)
+from .environments import (
+    PIPENV_MAX_DEPTH,
+    PIPENV_PIPFILE,
+    PIPENV_VENV_IN_PROJECT,
+    PIPENV_VIRTUALENV,
 )
-from .environments import PIPENV_MAX_DEPTH, PIPENV_VENV_IN_PROJECT
-from .environments import PIPENV_VIRTUALENV, PIPENV_PIPFILE
 
 if PIPENV_PIPFILE:
     if not os.path.isfile(PIPENV_PIPFILE):
         raise RuntimeError('Given PIPENV_PIPFILE is not found!')
     else:
-        PIPENV_PIPFILE = os.path.abspath(PIPENV_PIPFILE)
+        PIPENV_PIPFILE = normalize_drive(os.path.abspath(PIPENV_PIPFILE))
 
 
 class Project(object):
@@ -109,7 +115,10 @@ class Project(object):
 
     @property
     def project_directory(self):
-        return os.path.abspath(os.path.join(self.pipfile_location, os.pardir))
+        if self.pipfile_location is not None:
+            return os.path.abspath(os.path.join(self.pipfile_location, os.pardir))
+        else:
+            return None
 
     @property
     def requirements_exists(self):
@@ -221,7 +230,7 @@ class Project(object):
                 loc = pipfile.Pipfile.find(max_depth=PIPENV_MAX_DEPTH)
             except RuntimeError:
                 loc = None
-            self._pipfile_location = loc
+            self._pipfile_location = normalize_drive(loc)
 
         return self._pipfile_location
 
@@ -289,6 +298,15 @@ class Project(object):
         """A dictionary of the settings added to the Pipfile."""
         return self.parsed_pipfile.get('pipenv', {})
 
+    @property
+    def scripts(self):
+        scripts = self.parsed_pipfile.get('scripts', {})
+        for (k, v) in scripts.items():
+            scripts[k] = shlex.split(v, posix=True)
+
+        return scripts
+
+
     def update_settings(self, d):
         settings = self.settings
 
@@ -386,11 +404,24 @@ class Project(object):
 
     def create_pipfile(self, python=None):
         """Creates the Pipfile, filled with juicy defaults."""
+        config_parser = ConfigOptionParser(name=self.name)
+        install = dict(config_parser.get_config_section('install'))
+        indexes = install.get('extra-index-url', '').lstrip('\n').split('\n')
+
+        # Default source.
+        pypi_source = {u'url': u'https://pypi.python.org/simple', u'verify_ssl': True, u'name': 'pypi'}
+        sources = [pypi_source]
+
+        for i, index in enumerate(indexes):
+            if not index:
+                continue
+            source_name = 'pip_index_{}'.format(i)
+            verify_ssl = index.startswith('https')
+
+            sources.append({u'url': index, u'verify_ssl': verify_ssl, u'name': source_name})
+
         data = {
-            # Default source.
-            u'source': [
-                {u'url': u'https://pypi.python.org/simple', u'verify_ssl': True, 'name': 'pypi'}
-            ],
+            u'source': sources,
 
             # Default packages.
             u'packages': {},
